summaryrefslogtreecommitdiff
path: root/lib/libwebsockets.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/libwebsockets.h')
-rw-r--r--lib/libwebsockets.h6
1 files changed, 5 insertions, 1 deletions
diff --git a/lib/libwebsockets.h b/lib/libwebsockets.h
index a26df43..f8bfda4 100644
--- a/lib/libwebsockets.h
+++ b/lib/libwebsockets.h
@@ -65,6 +65,7 @@ enum libwebsocket_context_options {
enum libwebsocket_callback_reasons {
LWS_CALLBACK_ESTABLISHED,
+ LWS_CALLBACK_CLIENT_CONNECTION_ERROR,
LWS_CALLBACK_CLIENT_ESTABLISHED,
LWS_CALLBACK_CLOSED,
LWS_CALLBACK_RECEIVE,
@@ -249,7 +250,10 @@ struct libwebsocket_extension;
* LWS_CALLBACK_ESTABLISHED: after the server completes a handshake with
* an incoming client
*
* LWS_CALLBACK_CLIENT_ESTABLISHED: after your client connection completed
* a handshake with the remote server
*
* LWS_CALLBACK_CLOSED: when the websocket session ends
@@ -249,7 +250,10 @@ struct libwebsocket_extension;
* an incoming client
*
- * LWS_CALLBACK_CLIENT_ESTABLISHED: after your client connection completed
+ * LWS_CALLBACK_CLIENT_CONNECTION_ERROR: the request client connection has
+ * been unable to complete a handshake with the remote server
+ *
+ * LWS_CALLBACK_CLIENT_ESTABLISHED: after your client connection completed
* a handshake with the remote server
*